@@ -133,7 +133,7 @@ class SlicesAdminController(BaseAdminController):
 
     @expose()
     @require(predicates.in_group("acr"))
-    def delete(self, uid, came_from):
+    def delete(self, uid, came_from='js'):
         slice = DBSession.query(Slice).get(uid)
         if not user_can_modify(slice.page):
             flash('You do not have permissions to edit this page', 'error')
@@ -149,6 +149,8 @@ class SlicesAdminController(BaseAdminController):
             return redirect(url('/admin/pages/edit', uid=page.uid))
         elif came_from == 'groups':
             return redirect(url('/admin/slice_groups'))
+        else:
+            return 'OK'
 
     @expose()
     @require(predicates.in_group("acr"))
