@@ -126,7 +126,7 @@ class AcrRootController(TGController):
 
     @expose()
     def set_language(self, lang):
-        set_lang(lang);
+        set_lang(lang)
         return 'OK'
 
     @expose()
